==> jc-1.4.0.tar.gz: soot/baf/internal/BTrap.h <==
// public class soot.baf.internal.BTrap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 623521ce185a5943 soot_baf_internal_BTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_baf_internal_BTrap_H_
#define _JC_soot_baf_internal_BTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BTrap$sub_refs	_jc_soot_baf_internal_BTrap$sub_refs;
typedef struct _jc_soot_baf_internal_BTrap$sub_nonrefs	_jc_soot_baf_internal_BTrap$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BTrap$refs	_jc_soot_baf_internal_BTrap$refs;
typedef struct _jc_soot_baf_internal_BTrap$nonrefs	_jc_soot_baf_internal_BTrap$nonrefs;
typedef struct _jc_soot_baf_internal_BTrap$object	_jc_soot_baf_internal_BTrap$object;

typedef const struct _jc_soot_baf_internal_BTrap$vmethods	_jc_soot_baf_internal_BTrap$vmethods;
typedef const struct _jc_soot_baf_internal_BTrap$vtable	_jc_soot_baf_internal_BTrap$vtable;
typedef const struct _jc_soot_baf_internal_BTrap$vtype	_jc_soot_baf_internal_BTrap$vtype;

// Constructors
extern void _jc_soot_baf_internal_BTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BTrap$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_baf_internal_BTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *);
};

// Vtable
struct _jc_soot_baf_internal_BTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_baf_internal_BTrap$vmethods	soot_baf_internal_BTrap;
};

// Vtype
struct _jc_soot_baf_internal_BTrap$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BTrap$refs {
    _jc_soot_baf_internal_BTrap$sub_refs	soot_baf_internal_BTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_baf_internal_BTrap$sub_nonrefs	soot_baf_internal_BTrap;
};

// Object instance structure
struct _jc_soot_baf_internal_BTrap$object {
	_jc_soot_baf_internal_BTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BTrap$vtype	*vtype;
	_jc_soot_baf_internal_BTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BTrap$vtype _jc_soot_baf_internal_BTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BTrap$class_object;

#endif	/* _JC_soot_baf_internal_BTrap_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BTrap.h <==
// public class soot.baf.internal.BTrap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 623521ce185a5943 soot_baf_internal_BTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_baf_internal_BTrap_H_
#define _JC_soot_baf_internal_BTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BTrap$sub_refs	_jc_soot_baf_internal_BTrap$sub_refs;
typedef struct _jc_soot_baf_internal_BTrap$sub_nonrefs	_jc_soot_baf_internal_BTrap$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BTrap$refs	_jc_soot_baf_internal_BTrap$refs;
typedef struct _jc_soot_baf_internal_BTrap$nonrefs	_jc_soot_baf_internal_BTrap$nonrefs;
typedef struct _jc_soot_baf_internal_BTrap$object	_jc_soot_baf_internal_BTrap$object;

typedef const struct _jc_soot_baf_internal_BTrap$vmethods	_jc_soot_baf_internal_BTrap$vmethods;
typedef const struct _jc_soot_baf_internal_BTrap$vtable	_jc_soot_baf_internal_BTrap$vtable;
typedef const struct _jc_soot_baf_internal_BTrap$vtype	_jc_soot_baf_internal_BTrap$vtype;

// Constructors
extern void _jc_soot_baf_internal_BTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BTrap$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_baf_internal_BTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BTrap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_baf_internal_BTrap$vmethods	soot_baf_internal_BTrap;
};

// Vtype
struct _jc_soot_baf_internal_BTrap$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BTrap$refs {
    _jc_soot_baf_internal_BTrap$sub_refs	soot_baf_internal_BTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_baf_internal_BTrap$sub_nonrefs	soot_baf_internal_BTrap;
};

// Object instance structure
struct _jc_soot_baf_internal_BTrap$object {
	_jc_soot_baf_internal_BTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BTrap$vtype	*vtype;
	_jc_soot_baf_internal_BTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BTrap$vtype _jc_soot_baf_internal_BTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BTrap$class_object;

#endif	/* _JC_soot_baf_internal_BTrap_H_ */
